@@ -22,6 +22,14 @@ public:
     explicit InfoMotionWindow(QWidget *parent = 0);
     void loadMotionExercise(QString name);
 
+signals:
+    void closed();
+    void landscape();
+
+public slots:
+    void sendClosed();
+    void sendLandscape();
+
 private:
     SettingsWindow *sw;
     NewExerciseWindow *nw;
