@@ -89,7 +89,6 @@ void ListWindow::showInfo(QModelIndex index)
         imw = new InfoMotionWindow(this);
         connect(imw,SIGNAL(closed()),this,SLOT(sendClosed()));
         connect(imw,SIGNAL(landscape()),this, SLOT(sendLandscape()));
-        qDebug() << "b";
         imw->loadMotionExercise(index.data().toString());
         imw->show();
     }
@@ -112,7 +111,6 @@ void ListWindow::showHistory()
 void ListWindow::showSettings()
 {
     sw = new SettingsWindow(this);
-    sw->load();
     sw->show();
 }
 
