@@ -3,15 +3,15 @@
 #include <QDebug>
 
 NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
-    QMainWindow(parent)
+    QDialog(parent)
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
     setAttribute(Qt::WA_Maemo5LandscapeOrientation);
     setWindowTitle("New exercise");
     xml = new XML();
 
-    QWidget *widget = new QWidget();
-    setCentralWidget(widget);
+    //QWidget *widget = new QWidget();
+    //setCentralWidget(widget);
 
 
 
@@ -47,7 +47,7 @@ NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
     vLayout->addWidget(txtHowTo);
     vLayout->addWidget(btnSave);
 
-    widget->setLayout(vLayout);
+    setLayout(vLayout);
 
     connect(btnSave, SIGNAL(clicked()),this, SLOT(saveExercise()));
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
