@@ -8,7 +8,7 @@
 #include "xml.h"
 
 
-class NewExerciseWindow : public QMainWindow
+class NewExerciseWindow : public QDialog
 {
     Q_OBJECT
 public:
