@@ -25,14 +25,14 @@ StartWindow::StartWindow(QWidget *parent) :
     hLabelLayout->addWidget(lblCardio);
 
     QHBoxLayout *hButtonLayout = new QHBoxLayout;
-    btnWeight = new QPushButton(QIcon(":/images/images/weight.png"),"",this);
+    btnWeight = new QPushButton(QIcon(":/res/images/weight.png"),"",this);
     connect(btnWeight,SIGNAL(clicked()),this,SLOT(showWeight()));
 
-    btnCardio = new QPushButton(QIcon(":/images/images/cardio.png"),"",this);
+    btnCardio = new QPushButton(QIcon(":/res/images/cardio.png"),"",this);
     connect(btnCardio,SIGNAL(clicked()),this,SLOT(showCardio()));
-    btnProgram = new QPushButton(QIcon(":/images/images/program.png"),"",this);
+    btnProgram = new QPushButton(QIcon(":/res/images/program.png"),"",this);
 
-    btnFood = new QPushButton(QIcon(":/images/images/food.png"),"",this);
+    btnFood = new QPushButton(QIcon(":/res/images/food.png"),"",this);
     connect(btnFood,SIGNAL(clicked()),this, SLOT(showFood()));
 
     hButtonLayout->addWidget(btnWeight);
@@ -151,7 +151,7 @@ void StartWindow::checkIfFirstTime()
 {
     QFile file;
     if(!file.exists("/home/user/.qexercise/exercises.xml"))
-        xml->saveEx("Example","Arms","Biceps","Some info here");
+        xml->import(":/res/xml/startExercises.xml");
 
     if(!file.exists("/home/user/.qexercise/cardio.xml"))
         xml->saveCardio("Cardio");
@@ -186,7 +186,7 @@ void StartWindow::changeEvent(QEvent *event)
 
         if(!tmp.isEmpty())
         {
-            lblWeight->setText("Weight-lift \n " + tmp.takeFirst() + " kg/week \n "+ tmp.takeFirst() + " times/week");
+            lblWeight->setText("Weight-lifting \n " + tmp.takeFirst() + " kg/week \n "+ tmp.takeFirst() + " times/week");
             lblCardio->setText("Cardio \n" + tmp.takeFirst() + " km/week \n" + tmp.takeFirst() + " times/week");
         }
     }
@@ -241,7 +241,6 @@ void StartWindow::showCardio()
 void StartWindow::showSettings()
 {
     sw = new SettingsWindow(this);
-    sw->load();
     sw->show();
 }
 
